@@ -5,6 +5,10 @@ import json
 import datetime
 import secrets
 import time
+import threading
+import os
+import sys
+import psutil
 from jellyfin_accounts import (
     config,
     config_path,
@@ -61,7 +65,7 @@ def checkInvite(code, used=False, username=None):
                             if email.construct_expiry(
                                 {"code": invite, "expiry": expiry}
                             ):
-                                email.send()
+                                threading.Thread(target=email.send).start()
             del data_store.invites[invite]
         elif invite == code:
             match = True
@@ -222,7 +226,7 @@ def newUser():
                                     "created": datetime.datetime.now(),
                                 }
                             ):
-                                email.send()
+                                threading.Thread(target=email.send).start()
             if user.status_code == 200:
                 try:
                     policy = data_store.user_template
@@ -439,7 +443,7 @@ def modifyConfig():
     )
     temp_config.read(config_path)
     for section in data:
-        if section in temp_config:
+        if section in temp_config and 'restart-program' not in section:
             for item in data[section]:
                 temp_config[section][item] = data[section][item]
                 data[section][item] = True
@@ -447,7 +451,18 @@ def modifyConfig():
     with open(config_path, "w") as config_file:
         temp_config.write(config_file)
     config.trigger_reload()
-    log.info("Config written. Restart may be needed to load settings.")
+    log.info("Config written.")
+    if 'restart-program' in data:
+        if data['restart-program']:
+            log.info('Restarting...')
+            try:
+                proc = psutil.Process(os.getpid())
+                for handler in proc.open_files() + proc.connections():
+                    os.close(handler.fd)
+            except Exception as e:
+                log.error(f'Failed restart: {type(e).__name__}')
+            python = sys.executable
+            os.execl(python, python, *sys.argv)
     return resp()
 
 
